PaneSystemControllerProvider<T extends PaneTabData<T>> class
Properties
-
child
→ Widget
-
The widget below this widget in the tree.
finalinherited
-
controller
→ PaneSystemController<T>
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
key
→ Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement()
→ InheritedElement
-
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
emptyTabBuilder(BuildContext context)
→ Widget
-
-
emptyTabViewBuilder(BuildContext context, Pane<T> pane)
→ Widget
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
tabBuilder(BuildContext context, T data)
→ Widget
-
-
tabViewBuilder(BuildContext context, T data)
→ Widget
-
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited
-
updateShouldNotify(covariant PaneSystemControllerProvider<PaneTabData> old)
→ bool
-
Whether the framework should notify widgets that inherit from this widget.
override